==> knk-0.0.7.tgz: package/README.md <==
# knk

[![npm version][npm-image]][npm-url] [![mnt-image](https://img.shields.io/maintenance/yes/2021.svg?style=flat-square)](../../commits/master) [![Gitee stars](https://gitee.com/ipr-fe/knk/badge/star.svg?theme=dark)](https://gitee.com/artdong/vue-admin/stargazers)
[![npm download][download-image]][download-url] [![dumi](https://img.shields.io/badge/docs%20by-dumi-blue?style=flat-square)](https://gitee.com/umijs/dumi) [![Gitee license](https://img.shields.io/badge/license-MIT-blue.svg?style=flat-square)](https://gitee.com/ipr-fe/knk/blob/master/LICENSE)

[npm-image]: http://img.shields.io/npm/v/knk.svg?style=flat-square
[npm-url]: http://npmjs.org/package/knk
[download-image]: https://img.shields.io/npm/dm/knk.svg?style=flat-square
[download-url]: https://npmjs.org/package/knk
[bundlephobia-url]: https://bundlephobia.com/result?p=knk
[bundlephobia-image]: https://badgen.net/bundlephobia/minzip/knk

> react components based on react

## 📍 如何使用

### 安装

```bash
npm i knk
## or
yarn add knk
```

### 使用

[快速开始 →](https://ipr-fe.gitee.io/knk/)

## 📐 组件看板

- 基础组件
  - [SelectKeyWord 选择关键字](https://ipr-fe.gitee.io/knk/components/select_keyword)
  - [SelectTag 选择标签](https://ipr-fe.gitee.io/knk/components/select_tag)
  - [AjaxSelect 异步选择](https://ipr-fe.gitee.io/knk/components/ajax_select)
  - [CommonTable 通用表格](https://ipr-fe.gitee.io/knk/components/common_table)

## 🖥 浏览器兼容性

- 现代浏览器和 Internet Explorer 11 (with [polyfills](https://stackoverflow.com/questions/57020976/polyfills-in-2019-for-ie11))

| ![](https://raw.githubusercontent.com/alrra/browser-logos/master/src/edge/edge_48x48.png)<br>IE / Edge | ![](https://raw.githubusercontent.com/alrra/browser-logos/master/src/firefox/firefox_48x48.png)<br>Firefox | ![](https://raw.githubusercontent.com/alrra/browser-logos/master/src/chrome/chrome_48x48.png)<br>Chrome | ![](https://raw.githubusercontent.com/alrra/browser-logos/master/src/safari/safari_48x48.png)<br>Safari |
| ------------------------------------------------------------------------------------------------------ | ---------------------------------------------------------------------------------------------------------- | ------------------------------------------------------------------------------------------------------- | ------------------------------------------------------------------------------------------------------------- |
| IE11, Edge                                                                                             | last 2 versions                                                                                            | last 2 versions                                                                                         | last 2 versions                                                                                               |

## LICENSE

[MIT](https://gitee.com/ipr-fe/knk/blob/master/LICENSE)

==> knk-0.0.11.tgz: package/README.md <==
# knk

[![npm version][npm-image]][npm-url] [![mnt-image](https://img.shields.io/maintenance/yes/2021.svg?style=flat-square)](../../commits/master) [![Gitee stars](https://gitee.com/ipr-fe/knk/badge/star.svg?theme=dark)](https://gitee.com/artdong/vue-admin/stargazers)
[![npm download][download-image]][download-url] [![dumi](https://img.shields.io/badge/docs%20by-dumi-blue?style=flat-square)](https://gitee.com/umijs/dumi) [![Gitee license](https://img.shields.io/badge/license-MIT-blue.svg?style=flat-square)](https://gitee.com/ipr-fe/knk/blob/master/LICENSE)

[npm-image]: http://img.shields.io/npm/v/knk.svg?style=flat-square
[npm-url]: http://npmjs.org/package/knk
[download-image]: https://img.shields.io/npm/dm/knk.svg?style=flat-square
[download-url]: https://npmjs.org/package/knk
[bundlephobia-url]: https://bundlephobia.com/result?p=knk
[bundlephobia-image]: https://badgen.net/bundlephobia/minzip/knk

> react components based on react

## 📍 如何使用

### 安装

```
# use npm
npm i knk

# use yarn
yarn add knk
```

### 加入开发

#### 本地预览

```
# use npm
npm install
npm start

# use yarn
yarn install
yarn start
```

#### 发布文档

```
# use npm
npm run deploy

# use yarn
yarn deploy
```

#### 组件打包

```
# use npm
npm run compile

# use yarn
yarn compile
```

### 使用

[快速开始 →](https://ipr-fe.gitee.io/knk/)

## 📐 组件看板

- 基础组件
  - [AjaxManagerSelect 异步选择顾问](https://ipr-fe.gitee.io/knk/components/basic/ajax_manager_select)
  - [SelectKeyWord 选择关键字](https://ipr-fe.gitee.io/knk/components/basic/select_keyword)
  - [SelectTag 选择标签](https://ipr-fe.gitee.io/knk/components/basic/select_tag)
  - [AjaxSelect 异步选择](https://ipr-fe.gitee.io/knk/components/basic/ajax_select)
  - [AjaxTreeSelect 异步树选择](https://ipr-fe.gitee.io/knk/components/basic/ajax_tree_select)
  - [CommonTable 通用表格](https://ipr-fe.gitee.io/knk/components/basic/common_table)
  - [ImgPreview 图片预览](https://ipr-fe.gitee.io/knk/components/basic/img_preview)
  - [RmsFilesDown 获取RMS下载链接](https://ipr-fe.gitee.io/knk/components/basic/rms_files_down)
  - [AddressSelect 省市区级联组件](https://ipr-fe.gitee.io/knk/components/basic/address_select)
  - [PageTitle 通用页面title](https://ipr-fe.gitee.io/knk/components/basic/page_title)
  - [AjaxInputSearch 异步搜索](https://ipr-fe.gitee.io/knk/components/basic/ajax_input_search)

## 🖥 浏览器兼容性

- 现代浏览器和 Internet Explorer 11 (with [polyfills](https://stackoverflow.com/questions/57020976/polyfills-in-2019-for-ie11))

| ![](https://raw.githubusercontent.com/alrra/browser-logos/master/src/edge/edge_48x48.png)<br>IE / Edge | ![](https://raw.githubusercontent.com/alrra/browser-logos/master/src/firefox/firefox_48x48.png)<br>Firefox | ![](https://raw.githubusercontent.com/alrra/browser-logos/master/src/chrome/chrome_48x48.png)<br>Chrome | ![](https://raw.githubusercontent.com/alrra/browser-logos/master/src/safari/safari_48x48.png)<br>Safari |
| ------------------------------------------------------------------------------------------------------ | ---------------------------------------------------------------------------------------------------------- | ------------------------------------------------------------------------------------------------------- | ------------------------------------------------------------------------------------------------------------- |
| IE11, Edge                                                                                             | last 2 versions                                                                                            | last 2 versions                                                                                         | last 2 versions                                                                                               |

## LICENSE

[MIT](https://gitee.com/ipr-fe/knk/blob/master/LICENSE)
